package com.ruixuan.isc.entity;

import com.alibaba.fastjson.JSONObject;
import com.ruixuan.common.utils.DateUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;

/**
 * kwai售后单信息对象 kwaixiaodian_order_aftersales_list
 */
@Slf4j
@Data
public class KwaixiaodianOrderAftersalesList {
    /**
     * 公司ID
     */
    private Long companyId;


    /**
     * 公司名称
     */
    private String companyName;

    /**
     * 店铺ID
     */
    private Long shopId;

    /**
     * 店铺名称
     */
    private String shopName;
    /**
     * 售后单id
     */
    private Long refundId;

    /**
     * 订单ID
     */
    private Long oid;

    /**
     * 快手商品id
     */
    private Long itemId;

    /**
     * 快手商品skuid
     */
    private Long skuId;

    /**
     * 商家实退金额，包括退回给买家的现金/消费金/宠爱红包/平台补贴的所有资金，不包括主播红包退还金额
     */
    private Long refundFee;

    /**
     * 退款状态，枚举：[10, "买家已经申请退款，等待卖家同意"] [12, "卖家已拒绝，等待买家处理"] [20, "协商纠纷，等待平台处理"] [30, "卖家已经同意退款，等待买家退货"] [40, "买家已经退货，等待卖家确认收货"] [45, "卖家已经发货，等待买家确认收货"] [50, "卖家已经同意退款，等待系统执行退款"] [60, "退款成功"] [70, "退款关闭"]
     */
    private Long status;

    /**
     * 退款原因，数值格式，文案描述见refundReasonDesc
     */
    private Long refundReason;

    /**
     * 卖家快手id
     */
    private Long sellerId;

    /**
     * 退款类型，枚举： [1, "买家申请退款"] [2, "卖家主动退款"]
     */
    private Long refundType;

    /**
     * 退款方式，枚举： [1, "退货退款"] [10, "仅退款"] [3, "换货"]
     */
    private Long handlingWay;

    /**
     * 退款描述
     */
    private String refundDesc;

    /**
     * 物流id
     */
    private Long logisticsId;

    /**
     * 物流id
     */
    private String pictures;

    /**
     * 协商状态，枚举：[0, "未知状态"] [1, "待商家处理"] [2, "商家同意"] [3, "商家驳回，等待买家修改"]
     */
    private Long negotiateStatus;

    /**
     * 买家修改商家不同意的退款单时限
     */
    private Long validNegotiateBuyerModifyTimeStamp;

    /**
     * 服务商skuid
     */
    private Long relSkuId;

    /**
     * 服务商商品id
     */
    private Long relItemId;

    /**
     * 商家拒绝图片凭证
     */
    private String sellerDisagreeImages;

    /**
     * 退货单物流-快递单号
     */
    private String expressNo;

    /**
     * 退货单物流-快递公司编号
     */
    private String expressCode;

    /**
     * 商家拒绝文字说明
     */
    private String sellerDisagreeDesc;

    /**
     * 商家拒绝原因，枚举值可通过获取售后拒绝原因列表API（open.refund.reject.reason）获取
     */
    private Long sellerDisagreeReason;

    /**
     * 买家能修改WAIT_MODIFY的时间限制
     */
    private Long timeLimitNegotiateChange;

    /**
     * 协商状态变更原因。枚举值0:未知；10008:修改退款申请；10013：买家同意商家修改退款；10033:同意退款；10036：返回修改
     */
    private String negotiateReason;

    /**
     * 协商相关核心信息变更时间
     */
    private String negotiateUpdateTime;

    /**
     * 退货申请时间
     */
    private String submitTime;

    /**
     * 超期时间（商家处理的截止时间）
     */
    private String expireTime;

    /**
     * 结束时间（退款成功或退款失败时间）
     */
    private String endTime;

    /**
     * 加密后的买家id，同一个开发主体ISV下唯一，识别快手用户的唯一标识
     */
    private String buyerOpenId;

    /**
     * 卖家退货地址
     */
    private String address;

    /**
     * 特殊退款类型[0, "非特殊退款"] [1, "价保"]
     */
    private Long specialRefundType;

    /**
     * 退货包裹异常信息
     */
    private String logisticsRiskInfos;

    /**
     * 买家换货地址
     */
    private String buyerExchangeAddress;

    /**
     * 换货信息
     */
    private String exchangeInfo;

    /**
     * 商责运费信息
     */
    private String returnFreightInfo;
    /**
     * 订单创建时间
     */
    private String createTime;
    /**
     * 订单更新时间
     */
    private String updateTime;

    /**
     * 售后事件类型(类型枚举值后续可能会新增)
     * [0 "未知"], [2 "卖家拒绝退款"], [3 "卖家同意退款"], [4 "平台或买家修改退款记录"], [5 "卖家编辑后买家同意修改"], [6 "提交退货信息"], [7 "卖家确认收货"], [50 "退款打款中"], [60 "退款成功"], [70 "退款失败"]
     */
    private String eventType;

    public KwaixiaodianOrderAftersalesList() {
    }

    public KwaixiaodianOrderAftersalesList(KuaishouAccessToken token, JSONObject object) {
        try {
            KwaixiaodianOrderAftersalesList aftersales = JSONObject.parseObject(object.toJSONString(), KwaixiaodianOrderAftersalesList.class);
            aftersales.setCreateTime(DateUtils.timestamptoMinutesAndSecondsStr(object.getLong("createTime")));
            aftersales.setUpdateTime(DateUtils.timestamptoMinutesAndSecondsStr(object.getLong("updateTime")));
            aftersales.setNegotiateUpdateTime(DateUtils.timestamptoMinutesAndSecondsStr(object.getLong("negotiateUpdateTime")));
            aftersales.setSubmitTime(DateUtils.timestamptoMinutesAndSecondsStr(object.getLong("submitTime")));
            aftersales.setExpireTime(DateUtils.timestamptoMinutesAndSecondsStr(object.getLong("expireTime")));
            aftersales.setEndTime(DateUtils.timestamptoMinutesAndSecondsStr(object.getLong("endTime")));
            this.refundId = aftersales.refundId;
            this.oid = aftersales.oid;
            this.itemId = aftersales.itemId;
            this.skuId = aftersales.skuId;
            this.refundFee = aftersales.refundFee;
            this.status = aftersales.status;
            this.refundReason = aftersales.refundReason;
            this.sellerId = aftersales.sellerId;
            this.refundType = aftersales.refundType;
            this.handlingWay = aftersales.handlingWay;
            this.refundDesc = aftersales.refundDesc;
            this.logisticsId = aftersales.logisticsId;
            this.pictures = aftersales.pictures;
            this.negotiateStatus = aftersales.negotiateStatus;
            this.validNegotiateBuyerModifyTimeStamp = aftersales.validNegotiateBuyerModifyTimeStamp;
            this.relSkuId = aftersales.relSkuId;
            this.relItemId = aftersales.relItemId;
            this.sellerDisagreeImages = aftersales.sellerDisagreeImages;
            this.expressNo = aftersales.expressNo;
            this.expressCode = aftersales.expressCode;
            this.sellerDisagreeDesc = aftersales.sellerDisagreeDesc;
            this.sellerDisagreeReason = aftersales.sellerDisagreeReason;
            this.timeLimitNegotiateChange = aftersales.timeLimitNegotiateChange;
            this.negotiateReason = aftersales.negotiateReason;
            this.negotiateUpdateTime = aftersales.negotiateUpdateTime;
            this.submitTime = aftersales.submitTime;
            this.expireTime = aftersales.expireTime;
            this.endTime = aftersales.endTime;
            this.buyerOpenId = aftersales.buyerOpenId;
            this.address = aftersales.address;
            this.specialRefundType = aftersales.specialRefundType;
            this.logisticsRiskInfos = aftersales.logisticsRiskInfos;
            this.buyerExchangeAddress = aftersales.buyerExchangeAddress;
            this.exchangeInfo = aftersales.exchangeInfo;
            this.returnFreightInfo = aftersales.returnFreightInfo;
            this.createTime = aftersales.createTime;
            this.updateTime = aftersales.updateTime;
            this.eventType = aftersales.eventType;
            this.setShopId(Long.valueOf(token.getId()));
            this.setShopName(token.getShopName());
            this.setCompanyId(token.getCompanyId());
            this.setCompanyName(token.getCompanyName());
        } catch (NumberFormatException e) {
            log.error("格式转化错误");
            e.printStackTrace();
        }
    }
}
