package com.ruixuan.isc.service.impl;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.kuaishou.merchant.open.api.KsMerchantApiException;
import com.kuaishou.merchant.open.api.client.AccessTokenKsMerchantClient;
import com.kuaishou.merchant.open.api.common.utils.GsonUtils;
import com.kuaishou.merchant.open.api.request.distribution.OpenDistributionInvestmentActivityInvalidItemListRequest;
import com.kuaishou.merchant.open.api.request.distribution.OpenDistributionInvestmentActivityItemDetailRequest;
import com.kuaishou.merchant.open.api.request.distribution.OpenDistributionInvestmentActivityOpenItemListRequest;
import com.kuaishou.merchant.open.api.request.distribution.OpenDistributionPublicCategoryListRequest;
import com.kuaishou.merchant.open.api.response.distribution.OpenDistributionInvestmentActivityInvalidItemListResponse;
import com.kuaishou.merchant.open.api.response.distribution.OpenDistributionInvestmentActivityItemDetailResponse;
import com.kuaishou.merchant.open.api.response.distribution.OpenDistributionInvestmentActivityOpenItemListResponse;
import com.kuaishou.merchant.open.api.response.distribution.OpenDistributionPublicCategoryListResponse;
import com.ruixuan.common.utils.Check;
import com.ruixuan.isc.constants.KuaiShouConstants;
import com.ruixuan.isc.entity.JYOrderItemList;
import com.ruixuan.isc.entity.KuaishouAccessToken;
import com.ruixuan.isc.entity.KuaishouItemCategory;
import com.ruixuan.isc.entity.KuaishouItemList;
import com.ruixuan.isc.mapper.KuaishouItemListMapper;
import com.ruixuan.isc.mapper.SupplyChainMapper;
import com.ruixuan.isc.service.IKuaishouItemListService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2023-02-03
 */
@Service
@Slf4j
public class KuaishouItemListServiceImpl implements IKuaishouItemListService {
    @Autowired
    private KuaishouItemListMapper kuaishouItemListMapper;
    private static List<JSONObject> categoryIds;
    @Autowired
    private SupplyChainMapper supplyChainMapper;
    @Value("${ownership.id}")
    private String ownershipId;
    @Autowired
    private MongoTemplate mongoTemplate;

    @Override
    public List<KuaishouItemList> getItemList(Map<String, Object> requestMap) {
        List<KuaishouItemList> itemList = kuaishouItemListMapper.getItemList(requestMap);
        Map<Long, JSONObject> dataMap = new HashMap<>();
        if (!Check.isNull(itemList)) {
            Map<Long, Long> map = new HashMap<>();
            for (KuaishouItemList item : itemList) {
                map.put(item.getItemId(), item.getItemId());
            }
            List<JSONObject> itemInfoList = kuaishouItemListMapper.selectItemInfo(map);
            for (int i = 0; i < itemInfoList.size(); i++) {
                JSONObject jsonObject = itemInfoList.get(i);
                dataMap.put(jsonObject.getLong("itemId"), jsonObject);
            }
        }
        if (!Check.isNull(itemList)) {
            for (KuaishouItemList item : itemList) {
                Long itemId = item.getItemId();
                JSONObject jsonObject = dataMap.get(itemId);
                if (!Check.isNull(jsonObject)) {
                    item.setValidAmount(jsonObject.getLong("validAmount"));
                    item.setValidOrderNum(jsonObject.getLong("validOrderNum"));
                }
            }
        }
        return itemList;
    }

    @Override
    public JSONObject getItemDetail(Long regId, Long activityId, Long itemId, KuaishouAccessToken accessToken) throws Exception {
        // 调用爬虫信息
        JSONObject itemList = this.getInvestmentActivityOpenItemList(activityId, itemId, accessToken);
        JSONObject invalidJson = new JSONObject();
        if (!Check.isNull(itemList)) {
            invalidJson = itemList.getJSONObject("data");
        }
        JSONObject returnJson = new JSONObject();
        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, accessToken.getAppKey(), accessToken.getAppSecret());
        OpenDistributionInvestmentActivityItemDetailRequest request = new OpenDistributionInvestmentActivityItemDetailRequest();
        request.setAccessToken(accessToken.getAccessToken());
        request.setApiMethodVersion(1L);
        request.setActivityId(activityId);
        List<Long> item = new ArrayList<>();
        item.add(itemId);
        request.setItemId(item);
        OpenDistributionInvestmentActivityItemDetailResponse response = client.execute(request);
        JSONObject json = JSONObject.parseObject(GsonUtils.toJSON(response));
        if (Check.isNull(json)) {
            throw new Exception("获取商品信息出错，请重新提交");
        }
        Integer code = json.getInteger("code");
        Integer subCode = json.getInteger("sub_code");
        if (code == 1 && subCode == 1) {
            JSONArray data = json.getJSONArray("data");
            if (Check.isNull(data)) {
                returnJson.put("code", 500);
                returnJson.put("message", "数据查询失败");
                return returnJson;
            }
            JSONObject itemJson = data.getJSONObject(0);
            Long categoryId = itemJson.getLong("categoryId");
            JSONObject categoryInfo = getCategoryInfo(categoryId);
            if (!Check.isNull(categoryInfo)) {
                itemJson.put("categoryName", categoryInfo.getString("categoryName"));
                itemJson.put("categoryId", categoryInfo.getString("categoryId"));
            }
            itemJson.put("detailUrl", "https://app.kwaixiaodian.com/merchant/shop/detail?id=" + itemId);

            //  有效商品列表

            if (!Check.isNull(invalidJson)) {
                itemJson.put("regimentalPromotionRate", invalidJson.getLong("investmentPromotionRate"));
                itemJson.put("commissionRate", invalidJson.getLong("itemCommissionRate"));
            }

            returnJson.put("judgeStatus", 1);
            returnJson.put("itemJson", itemJson);
            returnJson.put("code", 0);
            returnJson.put("message", "查询成功");
        } else if (code != 1) { // 商品下线
            JSONObject invalidItemJson = new JSONObject();
            invalidItemJson.put("itemId", invalidJson.getLong("itemId"));
            invalidItemJson.put("itemTitle", invalidJson.getString("itemTitle"));
            invalidItemJson.put("itemDesc", invalidJson.getString("itemTitle"));
            invalidItemJson.put("itemPrice", invalidJson.getString("itemPrice"));
            invalidItemJson.put("itemImgUrl", invalidJson.getString("itemImgUrl"));
            invalidItemJson.put("itemDescUrls", invalidJson.getString("itemImgUrl"));
            invalidItemJson.put("activityId", activityId);
            invalidItemJson.put("activityItemStatus", invalidJson.getLong("itemAuditStatus"));
            invalidItemJson.put("commissionRate", invalidJson.getLong("itemCommissionRate"));
            invalidItemJson.put("detailUrl", "https://app.kwaixiaodian.com/merchant/shop/detail?id=" + itemId);
            invalidItemJson.put("regimentalPromotionRate", invalidJson.getLong("investmentPromotionRate"));
            invalidItemJson.put("categoryName", invalidJson.getString("itemCategoryName"));
            invalidItemJson.put("categoryId", invalidJson.getString("categoryId"));
            returnJson.put("judgeStatus", 2);
            returnJson.put("itemJson", invalidItemJson);
            returnJson.put("code", 0);
            returnJson.put("message", "查询成功");
            return returnJson;
        } else {
            returnJson.put("code", 500);
            returnJson.put("message", "数据查询失败");
        }
        log.info("获取商品信息回，活动ID：{},商品ID：{}，数据：{}", activityId, itemId, returnJson);
        return returnJson;
    }


    private JSONObject getCategoryInfo(Long categoryId) {
        if (Check.isNull(categoryId)) {
            return null;
        }
        JSONObject returnJson = new JSONObject();
        KuaishouItemCategory category = kuaishouItemListMapper.getCategoryInfo(categoryId);
        if (Check.isNull(category)) {
            return null;
        }
        Long parentId = category.getParentId();
        if (parentId == 0) {
            returnJson.put("categoryName", category.getCategoryName());
            returnJson.put("categoryId", categoryId);
            return returnJson;
        }
        StringBuilder stringBuild = new StringBuilder(category.getCategoryName());

        for (int i = 0; i < 10; i++) {
            stringBuild.insert(0, ">");
            category = kuaishouItemListMapper.getCategoryInfo(category.getParentId());
            stringBuild.insert(0, category.getCategoryName());
            if (category.getParentId() == 0) {
                categoryId = category.getCategoryId();
                break;
            }
        }
        returnJson.put("categoryName", stringBuild.toString());
        returnJson.put("categoryId", categoryId);
        return returnJson;
    }

    @Override
    public KuaishouItemList getItemInfoByItemId(Long itemId) {
        return kuaishouItemListMapper.getItemInfoByItemId(itemId);
    }


    @Override
    public void insertItem(KuaishouItemList kuaishouItemList) {
        Integer mediaId = kuaishouItemList.getMediaId();
        if (mediaId == 1) {
            kuaishouItemList.setOwnershipId("ruixuan");
        }

        String targetOwnershipId = kuaishouItemList.getOwnershipId(); // 目标数据库
        if (!targetOwnershipId.equals(ownershipId)) { // 如果目标数据库与当前连接数据库不一致 则去目标数据库查询用户信息
            JSONObject userInfo = kuaishouItemListMapper.getUserInfo(kuaishouItemList.getUserName(), targetOwnershipId);
            if (!Check.isNull(userInfo)) {
                kuaishouItemList.setUserId(userInfo.getLong("userId"));
                kuaishouItemList.setUserName(userInfo.getString("userName"));
            }
        }
        Long relateId = kuaishouItemListMapper.selectMaxRelateId(targetOwnershipId);
        if (Check.isNull(relateId)) {
            kuaishouItemList.setRelateId(1L);
        } else {
            kuaishouItemList.setRelateId(relateId + 1);
        }
        if (targetOwnershipId.equals("ruixuan")) {
            kuaishouItemListMapper.insertRuiXuanItem(kuaishouItemList);
        }
        if (targetOwnershipId.equals("miaogousi")) {
            kuaishouItemListMapper.insertMiaoGouSiItem(kuaishouItemList);
        }
        if (targetOwnershipId.equals("rocket")) {
            kuaishouItemListMapper.insertRocketItem(kuaishouItemList);
        }
        if (targetOwnershipId.equals("yufu")) {
            kuaishouItemListMapper.insertYufuItem(kuaishouItemList);
        }
        if (targetOwnershipId.equals("yuxiu")) {
            kuaishouItemListMapper.insertYuxiuItem(kuaishouItemList);
        }
        if (targetOwnershipId.equals("zhishui")) {
            kuaishouItemListMapper.insertZhishuiItem(kuaishouItemList);
        }
        JSONObject mongoVo = new JSONObject();
        mongoVo.put("_id", kuaishouItemList.getItemId());
        mongoVo.put("ownership", targetOwnershipId);
        mongoTemplate.save(mongoVo, "itemCheck");
        kuaishouItemListMapper.insertItemCheck(kuaishouItemList.getItemId(), targetOwnershipId);
        kuaishouItemListMapper.insertItemBindUser(kuaishouItemList.getItemId(), kuaishouItemList.getUserId(), kuaishouItemList.getUserName(), targetOwnershipId);
    }

    @Override
    public int updateKuaishouItemList(KuaishouItemList kuaishouItemList) {
        return kuaishouItemListMapper.updateKuaishouItemList(kuaishouItemList);
    }

    @Override
    public int deleteKuaishouItemListByItemIds(Long[] itemIds) {
        return kuaishouItemListMapper.deleteKuaishouItemListByItemIds(itemIds);
    }

    @Override
    public int addCategoryId(KuaishouAccessToken accessToken) throws KsMerchantApiException {
        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, accessToken.getAppKey(), accessToken.getSignSecret());
        OpenDistributionPublicCategoryListRequest request = new OpenDistributionPublicCategoryListRequest();
        request.setAccessToken(accessToken.getAccessToken());
        request.setApiMethodVersion(1L);
        OpenDistributionPublicCategoryListResponse response = client.execute(request);
        JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
        JSONArray data = jsonObject.getJSONArray("data");
        List<KuaishouItemCategory> adds = new ArrayList<>();
        for (int i = 0; i < data.size(); i++) {
            KuaishouItemCategory addCategory = new KuaishouItemCategory();
            JSONObject category = data.getJSONObject(i);
            Long categoryId = category.getLong("categoryId");
            String categoryName = category.getString("categoryName");
            Integer categorySort = category.getInteger("sortNum");
            Long categoryPid = category.getLong("categoryPid");
            addCategory.setCategoryId(categoryId);
            addCategory.setCategoryName(categoryName);
            addCategory.setCategorySort(categorySort);
            addCategory.setParentId(categoryPid);
            adds.add(addCategory);
            JSONArray childCategory = category.getJSONArray("childCategory");
            if (!Check.isNull(childCategory)) {
                for (int j = 0; j < childCategory.size(); j++) {
                    KuaishouItemCategory addCategory1 = new KuaishouItemCategory();
                    JSONObject category1 = childCategory.getJSONObject(j);
                    Long categoryId1 = category1.getLong("categoryId");
                    String categoryName1 = category1.getString("categoryName");
                    Integer categorySort1 = category1.getInteger("sortNum");
                    Long categoryPid1 = category1.getLong("categoryPid");
                    addCategory1.setCategoryId(categoryId1);
                    addCategory1.setCategoryName(categoryName1);
                    addCategory1.setCategorySort(categorySort1);
                    addCategory1.setParentId(categoryPid1);
                    adds.add(addCategory1);
                    JSONArray category2 = category1.getJSONArray("childCategory");
                    if (!Check.isNull(category2)) {
                        for (int k = 0; k < category2.size(); k++) {
                            KuaishouItemCategory addCategory2 = new KuaishouItemCategory();
                            JSONObject categoryJson2 = category2.getJSONObject(k);
                            Long categoryId2 = categoryJson2.getLong("categoryId");
                            String categoryName2 = categoryJson2.getString("categoryName");
                            Integer categorySort2 = categoryJson2.getInteger("sortNum");
                            Long categoryPid2 = categoryJson2.getLong("categoryPid");
                            addCategory2.setCategoryId(categoryId2);
                            addCategory2.setCategoryName(categoryName2);
                            addCategory2.setCategorySort(categorySort2);
                            addCategory2.setParentId(categoryPid2);
                            adds.add(addCategory2);
                            JSONArray category3 = categoryJson2.getJSONArray("childCategory");
                            if (!Check.isNull(category3)) {
                                for (int l = 0; l < category3.size(); l++) {
                                    KuaishouItemCategory addCategory3 = new KuaishouItemCategory();
                                    JSONObject categoryJson3 = category3.getJSONObject(l);
                                    Long categoryId3 = categoryJson3.getLong("categoryId");
                                    String categoryName3 = categoryJson3.getString("categoryName");
                                    Integer categorySort3 = categoryJson3.getInteger("sortNum");
                                    Long categoryPid3 = categoryJson3.getLong("categoryPid");
                                    addCategory3.setCategoryId(categoryId3);
                                    addCategory3.setCategoryName(categoryName3);
                                    addCategory3.setCategorySort(categorySort3);
                                    addCategory3.setParentId(categoryPid3);
                                    adds.add(addCategory3);
                                    JSONArray category4 = categoryJson3.getJSONArray("childCategory");
                                    if (!Check.isNull(category4)) {
                                        for (int m = 0; m < category4.size(); m++) {
                                            KuaishouItemCategory addCategory4 = new KuaishouItemCategory();
                                            JSONObject categoryJson4 = category4.getJSONObject(m);
                                            Long categoryId4 = categoryJson4.getLong("categoryId");
                                            String categoryName4 = categoryJson4.getString("categoryName");
                                            Integer categorySort4 = categoryJson4.getInteger("sortNum");
                                            Long categoryPid4 = categoryJson4.getLong("categoryPid");
                                            addCategory4.setCategoryId(categoryId4);
                                            addCategory4.setCategoryName(categoryName4);
                                            addCategory4.setCategorySort(categorySort4);
                                            addCategory4.setParentId(categoryPid4);
                                            adds.add(addCategory4);
                                            JSONArray category5 = categoryJson4.getJSONArray("childCategory");
                                            if (!Check.isNull(category5)) {
                                                for (int n = 0; n < category5.size(); n++) {
                                                    KuaishouItemCategory addCategory5 = new KuaishouItemCategory();
                                                    JSONObject categoryJson5 = category5.getJSONObject(n);
                                                    Long categoryId5 = categoryJson5.getLong("categoryId");
                                                    String categoryName5 = categoryJson5.getString("categoryName");
                                                    Integer categorySort5 = categoryJson5.getInteger("sortNum");
                                                    Long categoryPid5 = categoryJson5.getLong("categoryPid");
                                                    addCategory5.setCategoryId(categoryId5);
                                                    addCategory5.setCategoryName(categoryName5);
                                                    addCategory5.setCategorySort(categorySort5);
                                                    addCategory5.setParentId(categoryPid5);
                                                    adds.add(addCategory5);
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        kuaishouItemListMapper.batchCategory(adds);
        kuaishouItemListMapper.batchMgsCategory(adds);
        kuaishouItemListMapper.batchRocketCategory(adds);
        kuaishouItemListMapper.batchYufuCategory(adds);
        kuaishouItemListMapper.batchYuxiuCategory(adds);
        kuaishouItemListMapper.batchZhishuiCategory(adds);

        return 0;
    }

    @Override
    public List<JSONObject> getCategoryIds() {
        if (Check.isNull(categoryIds)) {
            categoryIds = kuaishouItemListMapper.getCategoryIds();
        }
        return categoryIds;
    }

    @Override
    public void updateCount(Long itemId, Integer sampleCount, Integer userCount) {
        kuaishouItemListMapper.updateCount(itemId, sampleCount, userCount);
    }

    @Override
    public List<Long> getActivityIds(Long userId) {
        return kuaishouItemListMapper.getActivityIds(userId);
    }

    @Override
    public Integer getSampleCount(Long itemId) {
        return kuaishouItemListMapper.getSampleCount(itemId);
    }

    @Override
    public void removeById(Long itemId) {
        kuaishouItemListMapper.removeById(itemId);
    }

    @Override
    public void batchItemProcess(JSONArray itemIds, Integer status, Long examineId, String examineName) {
        kuaishouItemListMapper.batchItemProcess(itemIds, status, examineId, examineName);
    }

    @Override
    public List<JSONObject> getRegimental() {
        return kuaishouItemListMapper.getRegimental();
    }

    @Override
    public List<JSONObject> getListByRelateId(Long relateId) {
        return kuaishouItemListMapper.getListByRelateId(relateId);
    }

    @Override
    public Long selectMaxRelateId(String ownershipId) {
        return kuaishouItemListMapper.selectMaxRelateId(ownershipId);
    }

    @Override
    public JSONObject selectRuleItemByItemId(Long itemId) {
        return kuaishouItemListMapper.selectRuleItemByItemId(itemId);
    }

    @Override
    public JSONObject getInvalidItemList(Long activityId, Long itemId, KuaishouAccessToken accessToken) {
        JSONObject returnJson = new JSONObject();
        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, accessToken.getAppKey(), accessToken.getSignSecret());
        OpenDistributionInvestmentActivityInvalidItemListRequest request = new OpenDistributionInvestmentActivityInvalidItemListRequest();
        request.setAccessToken(accessToken.getAccessToken());
        request.setApiMethodVersion(1L);
        request.setOffset("0");
        request.setItemId(itemId);
        request.setActivityId(activityId);
        request.setLimit(20);
        OpenDistributionInvestmentActivityInvalidItemListResponse response = null;
        try {
            response = client.execute(request);
        } catch (KsMerchantApiException e) {
            e.printStackTrace();
        }
        JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
        String code = jsonObject.getString("code");
        if ("1".equals(code)) {
            returnJson.put("code", 0);
            returnJson.put("message", "success");
            returnJson.put("data", jsonObject.getJSONObject("data").getJSONArray("item").getJSONObject(0));
            return returnJson;
        } else {
            returnJson.put("code", 500);
            returnJson.put("message", returnJson);
            return returnJson;
        }
    }

    @Override
    public JSONObject getInvestmentActivityOpenItemList(Long activityId, Long itemId, KuaishouAccessToken accessToken) {
        JSONObject returnJson = new JSONObject();
        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, accessToken.getAppKey(), accessToken.getSignSecret());

        OpenDistributionInvestmentActivityOpenItemListRequest request = new OpenDistributionInvestmentActivityOpenItemListRequest();
        request.setAccessToken(accessToken.getAccessToken());
        request.setApiMethodVersion(1L);

        request.setItemId(itemId);
        request.setActivityId(activityId);
        request.setLimit(20);

        OpenDistributionInvestmentActivityOpenItemListResponse response = null;
        try {
            response = client.execute(request);
        } catch (KsMerchantApiException e) {
            e.printStackTrace();
        }
        JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
        log.info(jsonObject.toJSONString());
        String code = jsonObject.getString("code");
        if ("1".equals(code)) {
            returnJson.put("code", 0);
            returnJson.put("message", "success");
            returnJson.put("data", jsonObject.getJSONObject("data").getJSONArray("activityItemDataList").getJSONObject(0));
            return returnJson;
        } else {
            returnJson.put("code", 500);
            returnJson.put("message", returnJson);
            return returnJson;
        }
    }

    @Override
    public List<JYOrderItemList> getJYOrderItemList(String itemTitle, String startDate, String endDate) {
        return kuaishouItemListMapper.getJYOrderItemList(itemTitle, startDate, endDate);
    }

    @Override
    public List<JSONObject> getDataOwnership() {
        return kuaishouItemListMapper.getDataOwnership();
    }

    @Override
    public Long checkUser(String ownershipId, String userName) {
        return kuaishouItemListMapper.checkUser(ownershipId, userName);
    }

    @Override
    public String selectDataOwnershipNameById(String ownershipId) {
        return kuaishouItemListMapper.selectDataOwnershipNameById(ownershipId);
    }

    @Override
    public String getItemOwnership(Long itemId) {
        return kuaishouItemListMapper.getItemOwnership(itemId);
    }

    @Override
    public List<JSONObject> getCleanData() {
        return kuaishouItemListMapper.getCleanData();
    }

    @Override
    public void insertItemCheck(Long itemId, String ownershipId) {
        kuaishouItemListMapper.insertItemCheck(itemId, ownershipId);
    }

    @Override
    public Integer checkItemData(String ownershipId, Long itemId) {
        return kuaishouItemListMapper.checkItemData(ownershipId, itemId);
    }


}

