package com.ruixuan.isc.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.kuaishou.merchant.open.api.KsMerchantApiException;
import com.kuaishou.merchant.open.api.client.AccessTokenKsMerchantClient;
import com.kuaishou.merchant.open.api.common.utils.GsonUtils;
import com.kuaishou.merchant.open.api.request.item.OpenItemGetRequest;
import com.kuaishou.merchant.open.api.request.item.OpenItemListGetRequest;
import com.kuaishou.merchant.open.api.response.item.OpenItemGetResponse;
import com.kuaishou.merchant.open.api.response.item.OpenItemListGetResponse;
import com.ruixuan.common.utils.Check;
import com.ruixuan.common.utils.DateUtils;
import com.ruixuan.isc.constants.KuaiShouConstants;
import com.ruixuan.isc.entity.KuaishouAccessToken;
import com.ruixuan.isc.entity.KwaixiaodianItemGet;
import com.ruixuan.isc.entity.KwaixiaodianItemGetSku;
import com.ruixuan.isc.mapper.KwaixiaodianItemGetMapper;
import com.ruixuan.isc.service.IKwaixiaodianItemGetService;
import com.ruixuan.system.service.ISysDeptService;
import com.ruixuan.system.service.ISysUserService;
import lombok.extern.slf4j.Slf4j;
import org.checkerframework.checker.units.qual.C;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * kwaixiaodian商品详情Service业务层处理
 *
 * @date 2024-10-28
 */
@Slf4j
@Service
public class KwaixiaodianItemGetServiceImpl implements IKwaixiaodianItemGetService {
    @Autowired
    private KwaixiaodianItemGetMapper mapper;
    @Autowired
    private ISysDeptService sysDeptService;
    @Autowired
    private ISysUserService sysUserService;

    /**
     * 添加数据 replace
     * 表:kwaixiaodian_item_get
     */
    @Override
    public JSONObject querykwaiItmInfo(KuaishouAccessToken token, Long kwaiItemId, String shopId, Long userId, String userName, Integer itemType, Long courtshipPurchaseId) {
        JSONObject returnJson = new JSONObject();
        try {

            AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, token.getAppKey(), token.getSignSecret());
            OpenItemGetRequest request = new OpenItemGetRequest();
            request.setAccessToken(token.getAccessToken());
            request.setApiMethodVersion(1L);
            request.setKwaiItemId(kwaiItemId);
            OpenItemGetResponse response = null;
            try {
                response = client.execute(request);
            } catch (KsMerchantApiException e) {
                e.printStackTrace();
            }
            JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
            String code = jsonObject.getString("code");
            if ("1".equals(code)) {
                JSONObject data = jsonObject.getJSONObject("data");
                KwaixiaodianItemGet itemGet = JSONObject.parseObject(data.toJSONString(), KwaixiaodianItemGet.class);

                if (!Check.isNull(courtshipPurchaseId)) {
                    itemGet.setCourtshipPurchaseId(courtshipPurchaseId);
                    String courtshipPurchaseName = sysUserService.getUserNameById(courtshipPurchaseId);
                    if (!Check.isNull(courtshipPurchaseName)) {
                        itemGet.setCourtshipPurchaseName(courtshipPurchaseName);
                    }
                }

                itemGet.setUserId(userId);
                itemGet.setItemType(itemType);
                itemGet.setUserName(userName);
                itemGet.setShopId(shopId);
                itemGet.setShopName(token.getShopName());
                itemGet.setCompanyId(token.getCompanyId());
                itemGet.setCompanyName(token.getCompanyName());
                itemGet.setLeaderName(token.getLeaderName());
                itemGet.setCreatedTimeMs(data.getLong("createdTime"));
                itemGet.setCreatedTime(DateUtils.timestamptoMinutesAndSecondsStr(itemGet.getCreatedTimeMs()));
                itemGet.setUpdateTimeMs(data.getLong("updateTime"));
                itemGet.setUpdateTime(DateUtils.timestamptoMinutesAndSecondsStr(itemGet.getUpdateTimeMs()));
                //ture-货品库存模式；false-商品库存模式     ->     1-货品库存模式；2-商品库存模式
                itemGet.setMultipleStock(data.getBoolean("multipleStock") ? "1" : "2");
                //是否限购，true:支持限购，false:不支持限购    ->    1:支持限购，0:不支持限购
                itemGet.setPurchaseLimit(data.getBoolean("purchaseLimit") ? "1" : "0");
                //是否是合约机商品，true:是，false:否    ->    1:是，0:否
                itemGet.setContractPhone(data.getBoolean("contractPhone") ? "1" : "0");
                Long price = getwaiItmPrice(token, kwaiItemId);
                itemGet.setPrice(price);
                JSONArray imageUrls = data.getJSONArray("imageUrls");
                if (!Check.isNull(imageUrls)) {
                    itemGet.setImageUrl(imageUrls.getString(0));
                }
                mapper.replaceKWaixiaodianItems(itemGet);
                replaceItemGetSku(data.getJSONArray("skuInfos"));
                returnJson.put("success", true);
            } else {
                returnJson.put("success", false);
                returnJson.put("message", jsonObject.getString("error_msg"));
                log.error("===kwaixiaodian获取商品详情（open.item.get）失败，kwaiItemId:{}，信息：{}", kwaiItemId, jsonObject.getString("error_msg"));

            }
        } catch (Exception e) {
            log.error("===kwaixiaodian获取商品详情异常 querykwaiItmInfo");
            e.printStackTrace();
            returnJson.put("success", false);
            returnJson.put("message", e.getMessage());
        }
        return returnJson;
    }

    /**
     * 从列表中拿单价 price
     * https://open.kwaixiaodian.com/zone/new/docs/api?name=open.item.list.get&version=1
     * open.item.list.get
     * 查询商品列表
     */
    public Long getwaiItmPrice(KuaishouAccessToken token, Long kwaiItemId) {
        JSONObject returnJson = new JSONObject();
        try {

            AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, token.getAppKey(), token.getSignSecret());

            OpenItemListGetRequest request = new OpenItemListGetRequest();
            request.setAccessToken(token.getAccessToken());
            request.setApiMethodVersion(1L);
            request.setKwaiItemId(kwaiItemId);
            OpenItemListGetResponse response = null;
            try {
                response = client.execute(request);
            } catch (KsMerchantApiException e) {
                e.printStackTrace();
            }
            JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
            String code = jsonObject.getString("code");
            if ("1".equals(code)) {
                JSONObject data = jsonObject.getJSONObject("data");
                JSONObject item = data.getJSONArray("items").getJSONObject(0);
                if (!Check.isNull(item)) {
                    return item.getLong("price");
                }
            } else {
                log.error("===kwaixiaodian查询商品列表失败，kwaiItemId:{}，信息：{}", kwaiItemId, jsonObject);
            }
        } catch (Exception e) {
            log.error("===kwaixiaodian查询商品列表异常 querykwaiItmInfo");
            e.printStackTrace();
        }
        return null;
    }


    @Override
    public Integer checkItem(Long companyId, Long itemId) {
        return mapper.checkItem(companyId, itemId);

    }


    @Override
    public Long getCompanyId(Long userId) {
        Long deptId = sysDeptService.getDeptIdByUserId(userId);
        String ancestors = sysDeptService.getCompanyId(deptId);

        Long companyId = null;
        if (!Check.isNull(ancestors)) {
            String[] split = ancestors.split(",");
            if (split.length == 1) {
                companyId = deptId;
            } else if (split.length > 1) {
                companyId = Long.valueOf(split[1]);
            } else {
                companyId = 0L;
            }
        }
        return companyId;
    }

    @Override
    public List<Long> getUserIds(Long userId) {
        Long deptId = sysDeptService.getDeptIdByUserId(userId);
        List<Long> userIds = sysDeptService.getDeptUserListByDeptId(deptId);
        return userIds;
    }

    @Override
    public List<KwaixiaodianItemGet> getItemList(Map<String, Object> requestMap) {
        return mapper.getItemList(requestMap);
    }

    @Override
    public List<JSONObject> getShopList(Long companyId) {
        return mapper.getShopList(companyId);
    }

    @Override
    public int deleteById(Long[] ids) {
        return mapper.deleteById(ids);
    }

    @Override
    public List<JSONObject> getCourtshipPurchaseIds(Long companyId) {
        List<Long> depts = mapper.getDeptIds(String.valueOf(companyId));
        if (Check.isNull(depts)) {
            return null;
        }
        List<JSONObject> userList = mapper.getCourtshipPurchaseIds(depts);
        return userList;
    }

    @Override
    public KwaixiaodianItemGet selectKwaixiaodianItemGetById(Long id) {
        return mapper.selectKwaixiaodianItemGetById(id);
    }

    @Override
    public int updateKwaixiaodianItemGet(KwaixiaodianItemGet kwaixiaodianItemGet) {
        if (!Check.isNull(kwaixiaodianItemGet.getCourtshipPurchaseId())) {
            String userName = sysUserService.getUserNameById(kwaixiaodianItemGet.getCourtshipPurchaseId());
            if (!Check.isNull(userName)) {
                kwaixiaodianItemGet.setCourtshipPurchaseName(userName);
            }

        }
        return mapper.updateKwaixiaodianItemGet(kwaixiaodianItemGet);
    }

    @Override
    public List<Long> getItemIdsByUserIds(List<Long> userIds) {
        return mapper.getItemIdsByUserIds(userIds);
    }

    @Override
    public List<JSONObject> getCompanyList() {
        return mapper.getCompanyList();
    }

    @Override
    public List<Long> getCourtshipPurchaseItemIdsByUserIds(List<Long> courtshipPurchaseIds) {
        return mapper.getCourtshipPurchaseItemIdsByUserIds(courtshipPurchaseIds);
    }


    private void replaceItemGetSku(JSONArray skuInfos) {
        try {
            if (Check.isNull(skuInfos)) {
                return;
            }
            List<KwaixiaodianItemGetSku> list = new ArrayList<>();
            for (int i = 0; i < skuInfos.size(); i++) {
                JSONObject data = skuInfos.getJSONObject(i);
                KwaixiaodianItemGetSku sku = JSONObject.parseObject(data.toJSONString(), KwaixiaodianItemGetSku.class);
                sku.setCreateTimeMs(data.getLong("createTime"));
                sku.setCreateTime(DateUtils.timestamptoMinutesAndSecondsStr(sku.getCreateTimeMs()));
                sku.setUpdateTimeMs(data.getLong("updateTime"));
                sku.setUpdateTime(DateUtils.timestamptoMinutesAndSecondsStr(sku.getUpdateTimeMs()));
                list.add(sku);
            }
            if (!Check.isNull(list) && list.size() > 0) {
                mapper.replaceBatchKWaixiaodianItemSku(list);
            }
        } catch (Exception e) {
            log.error("===kwaixiaodian获取商品详情异常 replaceItemGetSku");
            e.printStackTrace();
        }
    }

}
