package com.ruixuan.open.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.kuaishou.merchant.open.api.client.AccessTokenKsMerchantClient;
import com.kuaishou.merchant.open.api.common.utils.GsonUtils;
import com.kuaishou.merchant.open.api.request.video.OpenPhotoListRequest;
import com.kuaishou.merchant.open.api.response.video.OpenPhotoListResponse;
import com.ruixuan.common.utils.Check;
import com.ruixuan.common.utils.DateUtils;
import com.ruixuan.isc.constants.KuaiShouConstants;
import com.ruixuan.isc.entity.JYAccessToken;
import com.ruixuan.isc.mapper.AccessTokenMapper;
import com.ruixuan.open.entity.KuaishouOpenPhotoList;
import com.ruixuan.open.mapper.KuaishouOpenPhotoListMapper;
import com.ruixuan.open.service.IKuaishouOpenPhotoListService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 用户视频列Service业务层处理
 *
 * @author ruoyi
 * @date 2024-07-09
 */
@Slf4j
@Service
public class KuaishouOpenPhotoListServiceImpl implements IKuaishouOpenPhotoListService {
    @Autowired
    private KuaishouOpenPhotoListMapper kuaishouOpenPhotoListMapper;

    @Autowired
    private AccessTokenMapper accessTokenMapper;

    /**
     * 查询用户视频列
     *
     * @param id 用户视频列主键
     * @return 用户视频列
     */
    @Override
    public KuaishouOpenPhotoList selectKuaishouOpenPhotoListById(Long id) {
        return kuaishouOpenPhotoListMapper.selectKuaishouOpenPhotoListById(id);
    }

    /**
     * 查询用户视频列列表
     *
     * @param kuaishouOpenPhotoList 用户视频列
     * @return 用户视频列
     */
    @Override
    public List<KuaishouOpenPhotoList> selectKuaishouOpenPhotoListList(KuaishouOpenPhotoList kuaishouOpenPhotoList) {
        return kuaishouOpenPhotoListMapper.selectKuaishouOpenPhotoListList(kuaishouOpenPhotoList);
    }

    @Override
    public void insertKuaishouOpenPhotoList() {
        List<JYAccessToken> jyTokenInfos = accessTokenMapper.getJYTokenInfos();
        for (JYAccessToken tokenInfo : jyTokenInfos) {
            insertInfo(tokenInfo, null);
        }
    }

    @Override
    public void insertKuaishouOpenPhotoListByPromoter(Long promoterId) {
        JYAccessToken jyTokenInfo = accessTokenMapper.getJYTokenInfoByPromoter(promoterId);
        if (Check.isNull(jyTokenInfo)) {
            return;
        }
        insertInfo(jyTokenInfo, null);
    }

    private void insertInfo(JYAccessToken token, String cursor) {
        try {
            String appKey = token.getAppKey();
            String signSecret = token.getSignSecret();
            String accessToken = token.getAccessToken();
            AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, appKey, signSecret);

            OpenPhotoListRequest request = new OpenPhotoListRequest();
            request.setAccessToken(accessToken);
            request.setApiMethodVersion(1L);

            //游标，用于分页，值为作品id。分页查询时，传上一页create_time最小的photo_id。第一页不传此参数。
            request.setCursor(cursor);
            //数量，默认为20,最大不超过200
            request.setCount(200);

            OpenPhotoListResponse response = client.execute(request);
            JSONObject resultJson = JSONObject.parseObject(GsonUtils.toJSON(response));
            String code = resultJson.getString("code");
            String minPhotoId = null;
            if ("1".equals(code)) {
                List<KuaishouOpenPhotoList> list = new ArrayList<>();
                JSONArray jsonArray = resultJson.getJSONObject("data").getJSONArray("videoList");
                if (!Check.isNull(jsonArray)) {
                    Long min = jsonArray.getJSONObject(0).getLong("createTime");
                    for (int i = 0; i < jsonArray.size(); i++) {
                        JSONObject obj = jsonArray.getJSONObject(i);
                        KuaishouOpenPhotoList photo = JSONObject.parseObject(obj.toJSONString(), KuaishouOpenPhotoList.class);
                        //获取最小
                        if (obj.getLong("createTime") < min) {
                            min = obj.getLong("createTime");
                            minPhotoId = photo.getPhotoId();
                        }
                        photo.setPromoterId(Long.valueOf(token.getPromoterId()));
                        photo.setPhotoCreateTime(Long.valueOf(DateUtils.timestamptoStr(obj.getLong("createTime"))));
                        photo.setPending(String.valueOf(obj.getBoolean("pending") ? 1 : 0));
                        list.add(photo);
                    }
                }
                if (list.size() > 0) {
                    kuaishouOpenPhotoListMapper.replaceBatchKuaishouOpenPhotoList(list);
                }
                if (jsonArray.size() == 200) {
                    insertInfo(token, minPhotoId);
                }
            } else {
                log.error("===新增视频列表（open.photo.list）失败，promoterId:{}，信息：{}", token.getPromoterId(), resultJson.getString("msg"));
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

}
